pub unsafe extern "C" fn roaring_bitmap_and_cardinality(
r1: *const roaring_bitmap_t,
r2: *const roaring_bitmap_t,
) -> u64Expand description
Computes the size of the intersection between two bitmaps.
pub unsafe extern "C" fn roaring_bitmap_and_cardinality(
r1: *const roaring_bitmap_t,
r2: *const roaring_bitmap_t,
) -> u64Computes the size of the intersection between two bitmaps.