pub unsafe extern "C" fn roaring_bitmap_jaccard_index(
r1: *const roaring_bitmap_t,
r2: *const roaring_bitmap_t,
) -> f64Expand description
Computes the Jaccard index between two bitmaps. (Also known as the Tanimoto distance, or the Jaccard similarity coefficient)
The Jaccard index is undefined if both bitmaps are empty.