pub unsafe extern "C" fn roaring_bitmap_shrink_to_fit(
r: *mut roaring_bitmap_t,
) -> usizeExpand description
If needed, reallocate memory to shrink the memory usage. Returns the number of bytes saved.
pub unsafe extern "C" fn roaring_bitmap_shrink_to_fit(
r: *mut roaring_bitmap_t,
) -> usizeIf needed, reallocate memory to shrink the memory usage. Returns the number of bytes saved.